@@ -1,76 +1,25 @@
 # --- BEGIN COPYRIGHT BLOCK ---
-# Copyright (C) 2015 Red Hat, Inc.
+# Copyright (C) 2016 Red Hat, Inc.
 # All rights reserved.
 #
 # License: GPL (version 3 or any later version).
 # See LICENSE for details.
 # --- END COPYRIGHT BLOCK ---
 #
-import os
-import sys
-import time
-import ldap
-import logging
 import pytest
-from lib389 import DirSrv, Entry, tools, tasks
-from lib389.tools import DirSrvTools
-from lib389._constants import *
-from lib389.properties import *
 from lib389.tasks import *
 from lib389.utils import *
+from lib389.topologies import topology_st
+
+from lib389._constants import SUFFIX, DEFAULT_SUFFIX
 
 logging.getLogger(__name__).setLevel(logging.DEBUG)
 log = logging.getLogger(__name__)
 
-installation1_prefix = None
-
 UID_INDEX = 'cn=uid,cn=index,cn=userRoot,cn=ldbm database,cn=plugins,cn=config'
 
 
-logging.getLogger(__name__).setLevel(logging.DEBUG)
-log = logging.getLogger(__name__)
-
-installation1_prefix = None
-
-
-class TopologyStandalone(object):
-    def __init__(self, standalone):
-        standalone.open()
-        self.standalone = standalone
-
-
-@pytest.fixture(scope="module")
-def topology(request):
-    global installation1_prefix
-    if installation1_prefix:
-        args_instance[SER_DEPLOYED_DIR] = installation1_prefix
-
-    # Creating standalone instance ...
-    standalone = DirSrv(verbose=False)
-    args_instance[SER_HOST] = HOST_STANDALONE
-    args_instance[SER_PORT] = PORT_STANDALONE
-    args_instance[SER_SERVERID_PROP] = SERVERID_STANDALONE
-    args_instance[SER_CREATION_SUFFIX] = DEFAULT_SUFFIX
-    args_standalone = args_instance.copy()
-    standalone.allocate(args_standalone)
-    instance_standalone = standalone.exists()
-    if instance_standalone:
-        standalone.delete()
-    standalone.create()
-    standalone.open()
-
-    # Delete each instance in the end
-    def fin():
-        standalone.delete()
-    request.addfinalizer(fin)
-
-    # Clear out the tmp dir
-    standalone.clearTmpDir(__file__)
-
-    return TopologyStandalone(standalone)
-
-
-def test_ticket48109(topology):
+def test_ticket48109(topology_st):
     '''
     Set SubStr lengths to cn=uid,cn=index,...
       objectClass: extensibleObject
@@ -81,54 +30,54 @@ def test_ticket48109(topology):
     log.info('Test case 0')
     # add substr setting to UID_INDEX
     try:
-        topology.standalone.modify_s(UID_INDEX,
-                                     [(ldap.MOD_ADD, 'objectClass', 'extensibleObject'),
-                                      (ldap.MOD_ADD, 'nsIndexType', 'sub'),
-                                      (ldap.MOD_ADD, 'nsSubStrBegin', '2'),
-                                      (ldap.MOD_ADD, 'nsSubStrEnd', '2')])
+        topology_st.standalone.modify_s(UID_INDEX,
+                                        [(ldap.MOD_ADD, 'objectClass', 'extensibleObject'),
+                                         (ldap.MOD_ADD, 'nsIndexType', 'sub'),
+                                         (ldap.MOD_ADD, 'nsSubStrBegin', '2'),
+                                         (ldap.MOD_ADD, 'nsSubStrEnd', '2')])
     except ldap.LDAPError as e:
         log.error('Failed to add substr lengths: error ' + e.message['desc'])
         assert False
 
     # restart the server to apply the indexing
-    topology.standalone.restart(timeout=10)
+    topology_st.standalone.restart(timeout=10)
 
     # add a test user
     UID = 'auser0'
     USER_DN = 'uid=%s,%s' % (UID, SUFFIX)
     try:
-        topology.standalone.add_s(Entry((USER_DN, {
-                                         'objectclass': 'top person organizationalPerson inetOrgPerson'.split(),
-                                         'cn': 'a user0',
-                                         'sn': 'user0',
-                                         'givenname': 'a',
-                                         'mail': UID})))
+        topology_st.standalone.add_s(Entry((USER_DN, {
+            'objectclass': 'top person organizationalPerson inetOrgPerson'.split(),
+            'cn': 'a user0',
+            'sn': 'user0',
+            'givenname': 'a',
+            'mail': UID})))
     except ldap.LDAPError as e:
         log.error('Failed to add ' + USER_DN + ': error ' + e.message['desc'])
         assert False
 
-    entries = topology.standalone.search_s(SUFFIX, ldap.SCOPE_SUBTREE, '(uid=a*)')
+    entries = topology_st.standalone.search_s(SUFFIX, ldap.SCOPE_SUBTREE, '(uid=a*)')
     assert len(entries) == 1
 
     # restart the server to check the access log
-    topology.standalone.restart(timeout=10)
+    topology_st.standalone.restart(timeout=10)
 
-    cmdline = 'egrep %s %s | egrep "uid=a\*"' % (SUFFIX, topology.standalone.accesslog)
+    cmdline = 'egrep %s %s | egrep "uid=a\*"' % (SUFFIX, topology_st.standalone.accesslog)
     p = os.popen(cmdline, "r")
     l0 = p.readline()
     if l0 == "":
-        log.error('Search with "(uid=a*)" is not logged in ' + topology.standalone.accesslog)
+        log.error('Search with "(uid=a*)" is not logged in ' + topology_st.standalone.accesslog)
         assert False
     else:
-        #regex = re.compile('\(conn=[0-9]* op=[0-9]*\) SRCH .*')
+        # regex = re.compile('\(conn=[0-9]* op=[0-9]*\) SRCH .*')
         regex = re.compile(r'.*\s+(conn=\d+ op=\d+)\s+SRCH .*')
         match = regex.match(l0)
         log.info('match: %s' % match.group(1))
-        cmdline = 'egrep "%s" %s | egrep "RESULT"' % (match.group(1), topology.standalone.accesslog)
+        cmdline = 'egrep "%s" %s | egrep "RESULT"' % (match.group(1), topology_st.standalone.accesslog)
         p = os.popen(cmdline, "r")
         l1 = p.readline()
         if l1 == "":
-            log.error('Search result of "(uid=a*)" is not logged in ' + topology.standalone.accesslog)
+            log.error('Search result of "(uid=a*)" is not logged in ' + topology_st.standalone.accesslog)
             assert False
         else:
             log.info('l1: %s' % l1)
@@ -150,11 +99,11 @@ def test_ticket48109(topology):
 
     # clean up substr setting to UID_INDEX
     try:
-        topology.standalone.modify_s(UID_INDEX,
-                                     [(ldap.MOD_DELETE, 'objectClass', 'extensibleObject'),
-                                      (ldap.MOD_DELETE, 'nsIndexType', 'sub'),
-                                      (ldap.MOD_DELETE, 'nsSubStrBegin', '2'),
-                                      (ldap.MOD_DELETE, 'nsSubStrEnd', '2')])
+        topology_st.standalone.modify_s(UID_INDEX,
+                                        [(ldap.MOD_DELETE, 'objectClass', 'extensibleObject'),
+                                         (ldap.MOD_DELETE, 'nsIndexType', 'sub'),
+                                         (ldap.MOD_DELETE, 'nsSubStrBegin', '2'),
+                                         (ldap.MOD_DELETE, 'nsSubStrEnd', '2')])
     except ldap.LDAPError as e:
         log.error('Failed to delete substr lengths: error ' + e.message['desc'])
         assert False
@@ -168,53 +117,53 @@ def test_ticket48109(topology):
     log.info('Test case 1')
     # add substr setting to UID_INDEX
     try:
-        topology.standalone.modify_s(UID_INDEX,
-                                     [(ldap.MOD_ADD, 'nsIndexType', 'sub'),
-                                      (ldap.MOD_ADD, 'nsMatchingRule', 'nssubstrbegin=2'),
-                                      (ldap.MOD_ADD, 'nsMatchingRule', 'nssubstrend=2')])
+        topology_st.standalone.modify_s(UID_INDEX,
+                                        [(ldap.MOD_ADD, 'nsIndexType', 'sub'),
+                                         (ldap.MOD_ADD, 'nsMatchingRule', 'nssubstrbegin=2'),
+                                         (ldap.MOD_ADD, 'nsMatchingRule', 'nssubstrend=2')])
     except ldap.LDAPError as e:
         log.error('Failed to add substr lengths: error ' + e.message['desc'])
         assert False
 
     # restart the server to apply the indexing
-    topology.standalone.restart(timeout=10)
+    topology_st.standalone.restart(timeout=10)
 
     # add a test user
     UID = 'buser1'
     USER_DN = 'uid=%s,%s' % (UID, SUFFIX)
     try:
-        topology.standalone.add_s(Entry((USER_DN, {
-                                         'objectclass': 'top person organizationalPerson inetOrgPerson'.split(),
-                                         'cn': 'b user1',
-                                         'sn': 'user1',
-                                         'givenname': 'b',
-                                         'mail': UID})))
+        topology_st.standalone.add_s(Entry((USER_DN, {
+            'objectclass': 'top person organizationalPerson inetOrgPerson'.split(),
+            'cn': 'b user1',
+            'sn': 'user1',
+            'givenname': 'b',
+            'mail': UID})))
     except ldap.LDAPError as e:
         log.error('Failed to add ' + USER_DN + ': error ' + e.message['desc'])
         assert False
 
-    entries = topology.standalone.search_s(SUFFIX, ldap.SCOPE_SUBTREE, '(uid=b*)')
+    entries = topology_st.standalone.search_s(SUFFIX, ldap.SCOPE_SUBTREE, '(uid=b*)')
     assert len(entries) == 1
 
     # restart the server to check the access log
-    topology.standalone.restart(timeout=10)
+    topology_st.standalone.restart(timeout=10)
 
-    cmdline = 'egrep %s %s | egrep "uid=b\*"' % (SUFFIX, topology.standalone.accesslog)
+    cmdline = 'egrep %s %s | egrep "uid=b\*"' % (SUFFIX, topology_st.standalone.accesslog)
     p = os.popen(cmdline, "r")
     l0 = p.readline()
     if l0 == "":
-        log.error('Search with "(uid=b*)" is not logged in ' + topology.standalone.accesslog)
+        log.error('Search with "(uid=b*)" is not logged in ' + topology_st.standalone.accesslog)
         assert False
     else:
-        #regex = re.compile('\(conn=[0-9]* op=[0-9]*\) SRCH .*')
+        # regex = re.compile('\(conn=[0-9]* op=[0-9]*\) SRCH .*')
         regex = re.compile(r'.*\s+(conn=\d+ op=\d+)\s+SRCH .*')
         match = regex.match(l0)
         log.info('match: %s' % match.group(1))
-        cmdline = 'egrep "%s" %s | egrep "RESULT"' % (match.group(1), topology.standalone.accesslog)
+        cmdline = 'egrep "%s" %s | egrep "RESULT"' % (match.group(1), topology_st.standalone.accesslog)
         p = os.popen(cmdline, "r")
         l1 = p.readline()
         if l1 == "":
-            log.error('Search result of "(uid=*b)" is not logged in ' + topology.standalone.accesslog)
+            log.error('Search result of "(uid=*b)" is not logged in ' + topology_st.standalone.accesslog)
             assert False
         else:
             log.info('l1: %s' % l1)
@@ -236,10 +185,10 @@ def test_ticket48109(topology):
 
     # clean up substr setting to UID_INDEX
     try:
-        topology.standalone.modify_s(UID_INDEX,
-                                     [(ldap.MOD_DELETE, 'nsIndexType', 'sub'),
-                                      (ldap.MOD_DELETE, 'nsMatchingRule', 'nssubstrbegin=2'),
-                                      (ldap.MOD_DELETE, 'nsMatchingRule', 'nssubstrend=2')])
+        topology_st.standalone.modify_s(UID_INDEX,
+                                        [(ldap.MOD_DELETE, 'nsIndexType', 'sub'),
+                                         (ldap.MOD_DELETE, 'nsMatchingRule', 'nssubstrbegin=2'),
+                                         (ldap.MOD_DELETE, 'nsMatchingRule', 'nssubstrend=2')])
     except ldap.LDAPError as e:
         log.error('Failed to delete substr lengths: error ' + e.message['desc'])
         assert False
@@ -258,59 +207,59 @@ def test_ticket48109(topology):
 
     # add substr setting to UID_INDEX
     try:
-        topology.standalone.modify_s(UID_INDEX,
-                                     [(ldap.MOD_ADD, 'nsIndexType', 'sub'),
-                                      (ldap.MOD_ADD, 'nsMatchingRule', 'nssubstrbegin=3'),
-                                      (ldap.MOD_ADD, 'nsMatchingRule', 'nssubstrend=3'),
-                                      (ldap.MOD_ADD, 'objectClass', 'extensibleObject'),
-                                      (ldap.MOD_ADD, 'nsSubStrBegin', '2'),
-                                      (ldap.MOD_ADD, 'nsSubStrEnd', '2')])
+        topology_st.standalone.modify_s(UID_INDEX,
+                                        [(ldap.MOD_ADD, 'nsIndexType', 'sub'),
+                                         (ldap.MOD_ADD, 'nsMatchingRule', 'nssubstrbegin=3'),
+                                         (ldap.MOD_ADD, 'nsMatchingRule', 'nssubstrend=3'),
+                                         (ldap.MOD_ADD, 'objectClass', 'extensibleObject'),
+                                         (ldap.MOD_ADD, 'nsSubStrBegin', '2'),
+                                         (ldap.MOD_ADD, 'nsSubStrEnd', '2')])
     except ldap.LDAPError as e:
         log.error('Failed to add substr lengths: error ' + e.message['desc'])
         assert False
 
     # restart the server to apply the indexing
-    topology.standalone.restart(timeout=10)
+    topology_st.standalone.restart(timeout=10)
 
     # add a test user
     UID = 'cuser2'
     USER_DN = 'uid=%s,%s' % (UID, SUFFIX)
     try:
-        topology.standalone.add_s(Entry((USER_DN, {
-                                         'objectclass': 'top person organizationalPerson inetOrgPerson'.split(),
-                                         'cn': 'c user2',
-                                         'sn': 'user2',
-                                         'givenname': 'c',
-                                         'mail': UID})))
+        topology_st.standalone.add_s(Entry((USER_DN, {
+            'objectclass': 'top person organizationalPerson inetOrgPerson'.split(),
+            'cn': 'c user2',
+            'sn': 'user2',
+            'givenname': 'c',
+            'mail': UID})))
     except ldap.LDAPError as e:
         log.error('Failed to add ' + USER_DN + ': error ' + e.message['desc'])
         assert False
 
-    entries = topology.standalone.search_s(SUFFIX, ldap.SCOPE_SUBTREE, '(uid=c*)')
+    entries = topology_st.standalone.search_s(SUFFIX, ldap.SCOPE_SUBTREE, '(uid=c*)')
     assert len(entries) == 1
 
-    entries = topology.standalone.search_s(SUFFIX, ldap.SCOPE_SUBTREE, '(uid=*2)')
+    entries = topology_st.standalone.search_s(SUFFIX, ldap.SCOPE_SUBTREE, '(uid=*2)')
     assert len(entries) == 1
 
     # restart the server to check the access log
-    topology.standalone.restart(timeout=10)
+    topology_st.standalone.restart(timeout=10)
 
-    cmdline = 'egrep %s %s | egrep "uid=c\*"' % (SUFFIX, topology.standalone.accesslog)
+    cmdline = 'egrep %s %s | egrep "uid=c\*"' % (SUFFIX, topology_st.standalone.accesslog)
     p = os.popen(cmdline, "r")
     l0 = p.readline()
     if l0 == "":
-        log.error('Search with "(uid=c*)" is not logged in ' + topology.standalone.accesslog)
+        log.error('Search with "(uid=c*)" is not logged in ' + topology_st.standalone.accesslog)
         assert False
     else:
-        #regex = re.compile('\(conn=[0-9]* op=[0-9]*\) SRCH .*')
+        # regex = re.compile('\(conn=[0-9]* op=[0-9]*\) SRCH .*')
         regex = re.compile(r'.*\s+(conn=\d+ op=\d+)\s+SRCH .*')
         match = regex.match(l0)
         log.info('match: %s' % match.group(1))
-        cmdline = 'egrep "%s" %s | egrep "RESULT"' % (match.group(1), topology.standalone.accesslog)
+        cmdline = 'egrep "%s" %s | egrep "RESULT"' % (match.group(1), topology_st.standalone.accesslog)
         p = os.popen(cmdline, "r")
         l1 = p.readline()
         if l1 == "":
-            log.error('Search result of "(uid=c*)" is not logged in ' + topology.standalone.accesslog)
+            log.error('Search result of "(uid=c*)" is not logged in ' + topology_st.standalone.accesslog)
             assert False
         else:
             log.info('l1: %s' % l1)
@@ -330,22 +279,22 @@ def test_ticket48109(topology):
                 else:
                     log.info('Test case 2-1 - OK - correct substr index used')
 
-    cmdline = 'egrep %s %s | egrep "uid=\*2"' % (SUFFIX, topology.standalone.accesslog)
+    cmdline = 'egrep %s %s | egrep "uid=\*2"' % (SUFFIX, topology_st.standalone.accesslog)
     p = os.popen(cmdline, "r")
     l0 = p.readline()
     if l0 == "":
-        log.error('Search with "(uid=*2)" is not logged in ' + topology.standalone.accesslog)
+        log.error('Search with "(uid=*2)" is not logged in ' + topology_st.standalone.accesslog)
         assert False
     else:
-        #regex = re.compile('\(conn=[0-9]* op=[0-9]*\) SRCH .*')
+        # regex = re.compile('\(conn=[0-9]* op=[0-9]*\) SRCH .*')
         regex = re.compile(r'.*\s+(conn=\d+ op=\d+)\s+SRCH .*')
         match = regex.match(l0)
         log.info('match: %s' % match.group(1))
-        cmdline = 'egrep "%s" %s | egrep "RESULT"' % (match.group(1), topology.standalone.accesslog)
+        cmdline = 'egrep "%s" %s | egrep "RESULT"' % (match.group(1), topology_st.standalone.accesslog)
         p = os.popen(cmdline, "r")
         l1 = p.readline()
         if l1 == "":
-            log.error('Search result of "(uid=*2)" is not logged in ' + topology.standalone.accesslog)
+            log.error('Search result of "(uid=*2)" is not logged in ' + topology_st.standalone.accesslog)
             assert False
         else:
             log.info('l1: %s' % l1)
@@ -367,13 +316,13 @@ def test_ticket48109(topology):
 
     # clean up substr setting to UID_INDEX
     try:
-        topology.standalone.modify_s(UID_INDEX,
-                                     [(ldap.MOD_DELETE, 'nsIndexType', 'sub'),
-                                      (ldap.MOD_DELETE, 'nsMatchingRule', 'nssubstrbegin=3'),
-                                      (ldap.MOD_DELETE, 'nsMatchingRule', 'nssubstrend=3'),
-                                      (ldap.MOD_DELETE, 'objectClass', 'extensibleObject'),
-                                      (ldap.MOD_DELETE, 'nsSubStrBegin', '2'),
-                                      (ldap.MOD_DELETE, 'nsSubStrEnd', '2')])
+        topology_st.standalone.modify_s(UID_INDEX,
+                                        [(ldap.MOD_DELETE, 'nsIndexType', 'sub'),
+                                         (ldap.MOD_DELETE, 'nsMatchingRule', 'nssubstrbegin=3'),
+                                         (ldap.MOD_DELETE, 'nsMatchingRule', 'nssubstrend=3'),
+                                         (ldap.MOD_DELETE, 'objectClass', 'extensibleObject'),
+                                         (ldap.MOD_DELETE, 'nsSubStrBegin', '2'),
+                                         (ldap.MOD_DELETE, 'nsSubStrEnd', '2')])
     except ldap.LDAPError as e:
         log.error('Failed to delete substr lengths: error ' + e.message['desc'])
         assert False
