@@ -257,7 +257,7 @@ map {$conn{$_} = $_} @conncodes;
 
 # hash db-backed hashes
 my @hashnames = qw(attr rc src rsrc excount conn_hash ip_hash conncount nentries
-                   filter base ds6xbadpwd saslmech bindlist etime oid
+                   filter base ds6xbadpwd saslmech saslconnop bindlist etime oid
                    start_time_of_connection end_time_of_connection
                    notesa_conn_op notesu_conn_op etime_conn_op nentries_conn_op
                    optype_conn_op time_conn_op srch_conn_op del_conn_op mod_conn_op
@@ -1099,23 +1099,23 @@ print "Max BER Size Exceeded:        $maxBerSizeCount\n";
 print "\n";
 print "Binds:                        $bindCount\n";
 print "Unbinds:                      $unbindCount\n";
+print "------------------------------";
+print "-" x length $bindCount;
+print "\n";
 print " - LDAP v2 Binds:             $v2BindCount\n";
 print " - LDAP v3 Binds:             $v3BindCount\n";
-print " - AUTOBINDs:                 $autobindCount\n";
+print " - AUTOBINDs(LDAPI):          $autobindCount\n";
 print " - SSL Client Binds:          $sslClientBindCount\n";
 print " - Failed SSL Client Binds:   $sslClientFailedCount\n";
 print " - SASL Binds:                $saslBindCount\n";
 if ($saslBindCount > 0){
 	my $saslmech = $hashes->{saslmech};
 	foreach my $saslb ( sort {$saslmech->{$b} <=> $saslmech->{$a} } (keys %{$saslmech}) ){
-		printf "    %-4s - %s\n",$saslb, $saslmech->{$saslb};
+		printf "   - %-4s: %s\n",$saslb, $saslmech->{$saslb};
 	}
 }
-
 print " - Directory Manager Binds:   $rootDNBindCount\n";
 print " - Anonymous Binds:           $anonymousBindCount\n";
-my $otherBindCount = $bindCount -($rootDNBindCount + $anonymousBindCount);
-print " - Other Binds:               $otherBindCount\n\n";
 
 ##########################################################################
 #                       Verbose Logging Section                          #
@@ -1195,9 +1195,9 @@ if ($usage =~ /e/i || $verb eq "yes"){
 }
 
 ####################################
-#			   #
+#                                  #
 #     Print Failed Logins          #
-#				   #
+#                                  #
 ####################################
 
 if ($verb eq "yes" || $usage =~ /f/ ){
@@ -2117,7 +2117,7 @@ sub parseLineNormal
 		($connID) = $_ =~ /conn=(\d*)\s/;
 		handleConnClose($connID);
 	}
-	if (m/ BIND/ && $_ =~ /dn=\"(.*)\" method/i ){
+	if (m/ BIND / && $_ =~ /dn=\"(.*)\" method=128/i ){
 		my $binddn = $1;
 		if($reportStats){ inc_stats('bind',$s_stats,$m_stats); }
 		$bindCount++;
@@ -2531,10 +2531,62 @@ sub parseLineNormal
 			}
 		}
 	}
-	if (/ BIND / && /method=sasl/i){
+	if (/ BIND / && $_ =~ /dn=\"(.*)\" method=sasl/i){
+		my $binddn = $1;
+		my ($conn, $op);
 		$saslBindCount++;
+		$bindCount++;
 		if ($_ =~ /mech=(.*)/i ){
-			$hashes->{saslmech}->{$1}++;
+			my $mech = $1;
+			$hashes->{saslmech}->{$mech}++;
+			if ($_ =~ /conn= *([0-9A-Z]+) +op= *([0-9\-]+)/i){
+				$conn = $1;
+				$op = $2;
+				$hashes->{saslconnop}->{$conn-$op} = $mech;
+			}
+		}
+		if ($binddn ne ""){
+			if($binddn eq $rootDN){ $rootDNBindCount++; }
+			if($usage =~ /f/ || $usage =~ /u/ || $usage =~ /U/ || $usage =~ /b/ || $verb eq "yes"){
+				$tmpp = $binddn;
+				$tmpp =~ tr/A-Z/a-z/;
+				$hashes->{bindlist}->{$tmpp}++;
+				$hashes->{bind_conn_op}->{"$serverRestartCount,$conn,$op"} = $tmpp;
+			}
+		}
+	}
+	if (/ RESULT err=/ && / tag=97 nentries=0 etime=/ && $_ =~ /dn=\"(.*)\"/i){
+		# Check if this is a sasl bind, if see we need to add the RESULT's dn as a bind dn
+		my $binddn = $1;
+		my ($conn, $op);
+		if ($_ =~ /conn= *([0-9A-Z]+) +op= *([0-9\-]+)/i){
+			$conn = $1;
+			$op = $2;
+			if ($hashes->{saslconnop}->{$conn-$op} ne ""){
+				# This was a SASL BIND - record the dn
+				if ($binddn ne ""){
+					if($binddn eq $rootDN){ $rootDNBindCount++; }
+					if($usage =~ /f/ || $usage =~ /u/ || $usage =~ /U/ || $usage =~ /b/ || $verb eq "yes"){
+						$tmpp = $binddn;
+						$tmpp =~ tr/A-Z/a-z/;
+						$hashes->{bindlist}->{$tmpp}++;
+						$hashes->{bind_conn_op}->{"$serverRestartCount,$conn,$op"} = $tmpp;
+					}
+				}
+			}
+		}
+	}
+	if (/ RESULT err=14 tag=97 / && / SASL bind in progress/){
+		# Drop the sasl bind count since this is step in the bind process
+		$saslBindCount--;
+		$bindCount--;
+		$v3BindCount--;
+		my ($conn, $op);
+		if ($_ =~ /conn= *([0-9A-Z]+) +op= *([0-9\-]+)/i){
+			$conn = $1;
+			$op = $2;
+			my $mech = $hashes->{saslconnop}->{$conn-$op};
+			$hashes->{saslmech}->{$mech}--;
 		}
 	}
 	if (/ conn=Internal op=-1 / && !/ RESULT err=/){ $internalOpCount++; }
